Converter
=========

.. currentmodule:: curies

.. autoclass:: Converter
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Converter.compress
      ~Converter.expand
      ~Converter.expand_pair
      ~Converter.from_jsonld
      ~Converter.from_jsonld_github
      ~Converter.from_jsonld_url
      ~Converter.from_prefix_map
      ~Converter.from_reverse_prefix_map
      ~Converter.parse_uri

   .. rubric:: Methods Documentation

   .. automethod:: compress
   .. automethod:: expand
   .. automethod:: expand_pair
   .. automethod:: from_jsonld
   .. automethod:: from_jsonld_github
   .. automethod:: from_jsonld_url
   .. automethod:: from_prefix_map
   .. automethod:: from_reverse_prefix_map
   .. automethod:: parse_uri
